# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import hr_holidays_cancel_leave
from . import hr_holidays_summary_employees
from . import hr_departure_wizard
from . import hr_leave_generate_multi_wizard
from . import hr_leave_allocation_generate_multi_wizard
